ClojureScript only.

threeagent.assets.impl.zip


load-zip!cljs

(load-zip! database
           zip-url
           asset-tree
           {:keys [base-path on-progress on-download-progress]})

Loads assets from a zip file into the asset database.

Options: :base-path - Path prefix inside the zip to strip (e.g. "assets" if zip contains assets/models/foo.glb) :on-progress - Optional (fn [loaded total]) called after each asset loads. :on-download-progress - Optional (fn [bytes-loaded bytes-total]) called while the zip file is downloading. bytes-total is nil when the server does not provide a reliable Content-Length. Always fires once at completion with (final, final).

Returns a Promise that resolves when all assets are loaded.

Loads assets from a zip file into the asset database.

Options:
  :base-path             - Path prefix inside the zip to strip (e.g. "assets" if zip contains assets/models/foo.glb)
  :on-progress           - Optional (fn [loaded total]) called after each asset loads.
  :on-download-progress  - Optional (fn [bytes-loaded bytes-total]) called while
                           the zip file is downloading. bytes-total is nil when
                           the server does not provide a reliable Content-Length.
                           Always fires once at completion with (final, final).

Returns a Promise that resolves when all assets are loaded.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries